@@ -1,6 +1,9 @@
 from __future__ import annotations
 
+from functools import reduce
 from pathlib import Path
+from textwrap import dedent
+from time import sleep
 from typing import TYPE_CHECKING
 
 import pytest
@@ -21,7 +24,7 @@ from tests.util import (
 )
 
 if TYPE_CHECKING:
-    from typing import Generator, Literal, Protocol, TypedDict, Union
+    from typing import Generator, Protocol, TypedDict, Union
 
     from semantic_release.hvcs import HvcsBase
 
@@ -34,7 +37,7 @@ if TYPE_CHECKING:
         UseParserFn,
     )
 
-    CommitConvention = Literal["angular", "emoji", "scipy", "tag"] | str
+    CommitConvention = str
     VersionStr = str
     CommitMsg = str
     ChangelogTypeHeading = str
@@ -50,6 +53,11 @@ if TYPE_CHECKING:
         changelog_sections: list[ChangelogTypeHeadingDef]
         commits: list[CommitMsg]
 
+    class BaseAccumulatorVersionReduction(TypedDict):
+        limit_value: str
+        limit_found: bool
+        repo_def: dict[VersionStr, RepoVersionDef]
+
     class ChangelogTypeHeadingDef(TypedDict):
         section: ChangelogTypeHeading
         i_commits: list[int]
@@ -107,6 +115,7 @@ if TYPE_CHECKING:
             self,
             repo_definition: RepoDefinition,
             dest_file: Path | None = None,
+            max_version: str | None = None,
         ) -> str: ...
 
 
@@ -151,10 +160,14 @@ def create_release_tagged_commit(
         # commit --all files with version number commit message
         git_repo.git.commit(a=True, m=COMMIT_MESSAGE.format(version=version))
 
+        sleep(1)  # ensure commit timestamps are unique
+
         # tag commit with version number
         tag_str = tag_format.format(version=version)
         git_repo.git.tag(tag_str, m=tag_str)
 
+        sleep(1)  # ensure commit timestamps are unique
+
     return _mimic_semantic_release_commit
 
 
@@ -193,6 +206,7 @@ def simulate_change_commits_n_rtn_changelog_entry(
             changelog_entries.append(
                 commit_n_rtn_changelog_entry(git_repo, commit_msg, hvcs)
             )
+            sleep(1)  # ensure commit timestamps are unique
         return changelog_entries
 
     return _simulate_change_commits_n_rtn_changelog_entry
@@ -231,6 +245,7 @@ def cached_example_git_project(
             config.set_value("user", "name", commit_author.name)
             config.set_value("user", "email", commit_author.email)
             config.set_value("commit", "gpgsign", False)
+            config.set_value("tag", "gpgsign", False)
 
         repo.create_remote(name="origin", url=example_git_https_url)
 
@@ -325,37 +340,73 @@ def build_configured_base_repo(  # noqa: C901
 
 
 @pytest.fixture(scope="session")
-def simulate_default_changelog_creation() -> SimulateDefaultChangelogCreationFn:
+def simulate_default_changelog_creation(
+    default_md_changelog_insertion_flag: str,
+) -> SimulateDefaultChangelogCreationFn:
+    def reduce_repo_def(
+        acc: BaseAccumulatorVersionReduction, ver_2_def: tuple[str, RepoVersionDef]
+    ) -> BaseAccumulatorVersionReduction:
+        if acc["limit_found"]:
+            return acc
+
+        if ver_2_def[0] == acc["limit_value"]:
+            acc["limit_found"] = True
+
+        acc["repo_def"][ver_2_def[0]] = ver_2_def[1]
+        return acc
+
     def build_version_entry(version: VersionStr, version_def: RepoVersionDef) -> str:
         version_entry = []
         if version == "Unreleased":
             version_entry.append(f"## {version}\n")
         else:
-            version_entry.append(
-                # TODO: artificial newline in front due to template when no Unreleased changes exist
-                f"\n## v{version} ({TODAY_DATE_STR})\n"
-            )
+            version_entry.append(f"## v{version} ({TODAY_DATE_STR})\n")
 
         for section_def in version_def["changelog_sections"]:
             version_entry.append(f"### {section_def['section']}\n")
-            for i in section_def["i_commits"]:
-                version_entry.append(f"* {version_def['commits'][i]}\n")
+            version_entry.extend(
+                [f"* {version_def['commits'][i]}\n" for i in section_def["i_commits"]]
+            )
 
         return str.join("\n", version_entry)
 
     def _mimic_semantic_release_default_changelog(
         repo_definition: RepoDefinition,
         dest_file: Path | None = None,
+        max_version: str | None = None,
     ) -> str:
-        header = "# CHANGELOG"
+        header = dedent(
+            f"""\
+            # CHANGELOG
+
+            {default_md_changelog_insertion_flag}
+            """
+        ).rstrip()
+
         version_entries = []
 
-        for version, version_def in repo_definition.items():
+        repo_def = (
+            repo_definition
+            if max_version is None
+            else reduce(
+                reduce_repo_def,
+                repo_definition.items(),
+                {
+                    "limit_value": max_version,
+                    "limit_found": False,
+                    "repo_def": {},
+                },
+            )["repo_def"]
+        )
+
+        for version, version_def in repo_def.items():
             # prepend entries to force reverse ordering
             version_entries.insert(0, build_version_entry(version, version_def))
 
         changelog_content = (
-            str.join("\n" * 3, [header, str.join("\n", list(version_entries))]).rstrip()
+            str.join(
+                "\n" * 2, [header, str.join("\n" * 2, list(version_entries))]
+            ).rstrip()
             + "\n"
         )
 
